import React from 'react';
import { motion } from 'framer-motion';
import { Server, Container, Box, Cloud, Terminal, Database } from 'lucide-react';

const technologies = [
  { icon: Server, name: 'Infrastructure', desc: 'Lenovo System x3950 X6, Dell R620' },
  { icon: Container, name: 'Containerization', desc: 'Docker, Podman' },
  { icon: Cloud, name: 'Virtualization', desc: 'Proxmox' },
  { icon: Terminal, name: 'DevOps', desc: 'CI/CD, Automation' },
  { icon: Database, name: 'Database', desc: 'Management & Optimization' },
  { icon: Box, name: 'Custom Builds', desc: 'Self-made Infrastructure' },
];

export default function TechStack() {
  return (
    <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6 w-full max-w-6xl mx-auto">
      {technologies.map((tech, index) => (
        <motion.div
          key={tech.name}
          initial={{ opacity: 0, y: 20 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.5, delay: index * 0.1 }}
          className="bg-gray-800 p-6 rounded-xl hover:bg-gray-700 transition-colors"
        >
          <div className="flex items-center space-x-4">
            <tech.icon className="w-8 h-8 text-cyan-400" />
            <div>
              <h3 className="text-xl font-bold text-white">{tech.name}</h3>
              <p className="text-gray-400">{tech.desc}</p>
            </div>
          </div>
        </motion.div>
      ))}
    </div>
  );
}